%pdf_plot
% Function which creates a PNG file of name plot_name based upon
% statistical data stored in structure s. A probability density function
% (overlaid with a fitted normal distribution) is plotted, plus statistical
% parameters as an annotation. A box & whisker plot is placed underneath
% the graph.

function pdf_plot(s, xlimits, ylimits, x_label, plot_title, plot_name, plot_color,  fig )

%Create figure if fig is empty []
if isempty(fig)
    fig = figure('name','pdf_plot','color',[1 1 1],'renderer','opengl');
end

%Plot histogram
b = bar( s.x_bin_edges, s.pdf,'histc');
set(b,'facecolor',plot_color,'edgecolor',plot_color)
xlim(xlimits)
ylim(ylimits)
grid on
box on
xlabel(x_label)
ylabel('Normalized frequency density')
title({ strrep( plot_title, '_','\_'),...
    ['N = ',num2str(s.N),', min = ',num2str(s.min_x),...
    ', max = ',num2str(s.max_x),', range = ',num2str(s.range_x) ],...
    ['mean = ',num2str(s.mean),', median = ',num2str(s.median),...
    ', std = ',num2str(s.std),', skew = ',num2str(s.skew),...
    ', kurtosis = ',num2str(s.kurtosis)] })

%Plot box and whisker
hold on; axis manual;
dy = ylimits(2) - ylimits(1);
p = patch( [s.LQ, s.UQ, s.UQ, s.LQ ], [-0.05*dy,-0.05*dy,0,0]+ylimits(2),'r','facealpha',0.5 );
plot( [s.median,s.median],[-0.05*dy,0]+ylimits(2),'k-' );
plot( [s.mean,s.mean],[-0.05*dy,0]+ylimits(2),'m-' );

%Overlay normal distribution
plot( s.x_sort, s.norm_fit,'k' );

%Print PG and close figure
print(fig,plot_name,'-dpng','-r300');
close(fig);

%%

function pdf_plot_test
s = statistica( randn(1,10000), -2*pi, 2*pi, 0.01 );

%PDF plot
pdf_plot(s, [-2*pi,2*pi], [0,max(s.pdf)], 'x', 'pdf_plot_test', 'pdf_plot_test',[0,1,0], [] );

%Cumulative frequency plot
fig = figure('color',[1 1 1],'name','Normalized cumulative frequency %','renderer','opengl');
plot( s.x_sort, s.cumfreq ); 
xlabel('x');
ylabel('Normalized cumulative frequency %')
title('Normalized cumulative frequency %');
hold on;
ylimits = get(gca,'ylim');
dy = diff(ylim);
p = patch( [s.LQ, s.UQ, s.UQ, s.LQ ], [-0.05*dy,-0.05*dy,0,0]+ylimits(2),'r','facealpha',0.5 );
plot( [s.median,s.median],[-0.05*dy,0]+ylimits(2),'k-' );
plot( [s.mean,s.mean],[-0.05*dy,0]+ylimits(2),'m-' );
grid on;
box on;
print(fig,'pdf_plot_test_cum_freq','-dpng','-r300');
close(fig);

%End of code